@@ -28,3 +28,16 @@ test_that("test Translator general", {
                               translation_csvs_path = "data"),
                "mutually exclusive")
 })
+
+test_that("test vector translations", {
+  i18n <- Translator$new(translation_json_path = "data/translation.json")
+  expect_equal(i18n$t(c("Hello Shiny!")), "Hello Shiny!")
+  i18n$set_translation_language("pl")
+  expect_equal(i18n$t(c("Hello Shiny!")), "Witaj Shiny!")
+  expect_warning(i18n$t(c("Hello Shiny!", "Text")))
+  expect_equal(i18n$t(c("Hello Shiny!", "Text")), c("Witaj Shiny!", "Text"))
+  expect_equal(i18n$t(c("Hello Shiny!", "Text", "Frequency")),
+               c("Witaj Shiny!", "Text", "Częstotliwość"))
+  expect_warning(i18n$t(c("Hello Shiny!", "X")),
+                 regexp = "'X' translation does not exist.")
+})
